==> extension_llvm-19.1.7.tar.xz: extension_llvm-19.1.7/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

source /etc/profile
#unset CPLUS_INCLUDE_PATH

# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(command -v git) == "" ]] && echo "Installing git" && extension --install git && echo "Finished git"
	[[ $(command -v gc) == "" ]] && echo "Installing graphviz" && extension --install graphviz && echo "Finished graphviz"
	[[ $(command -v xmllint) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
	[ ! -d /usr/lib/python*/site-packages/psutil-* ] && echo "Installing py_psutil" && extension --install py_psutil && echo "Finished py_psutil"
	[[ $(command -v pygmentize) == "" ]] && echo "Installing py_pygments" && extension --install py_pygments && echo "Finished py_pygments"
	[ -d /usr/lib/python*/site-packages/PyYAML-* ] && echo "Installing py_pyyaml" && extension --install py_pyyaml && echo "Finished py_pyyaml"
	[[ $(command -v rsync) == "" ]] && echo "Installing rsync" && extension --install rsync && echo "Finished rsync"
	#[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
	[[ $(command -v texdoc) == "" ]] && echo "Installing texlive" && extension --install texlive && echo "Finished texlive"
	[[ $(command -v valgrind) == "" ]] && echo "Installing valgrind" && extension --install valgrind && echo "Finished valgrind"
	[[ $(command -v zip) == "" ]] && echo "Installing zip" && extension --install zip && echo "Finished zip"
	#[[ $(command -v myst-parser) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	#[[ $(command -v OCaml) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	[[ $(command -v Z3) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v clang) == "" ]]; then
	echo "llvm" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "llvm" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt

==> extension_llvm-20.1.8.tar.xz: extension_llvm-20.1.8/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

source /etc/profile
#unset CPLUS_INCLUDE_PATH

# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(command -v git) == "" ]] && echo "Installing git" && extension --install git && echo "Finished git"
	[[ $(command -v gc) == "" ]] && echo "Installing graphviz" && extension --install graphviz && echo "Finished graphviz"
	[ ! -f /usr/lib/libunwind.so ] && echo "Installing libunwind" && extension --install libunwind && echo "Finished libunwind"
	[[ $(command -v xmllint) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
	[ ! -d /usr/lib/python*/site-packages/psutil-* ] && echo "Installing py_psutil" && extension --install py_psutil && echo "Finished py_psutil"
	[[ $(command -v pygmentize) == "" ]] && echo "Installing py_pygments" && extension --install py_pygments && echo "Finished py_pygments"
	[ -d /usr/lib/python*/site-packages/PyYAML-* ] && echo "Installing py_pyyaml" && extension --install py_pyyaml && echo "Finished py_pyyaml"
	[[ $(command -v rsync) == "" ]] && echo "Installing rsync" && extension --install rsync && echo "Finished rsync"
	[[ $(command -v sphinx-autogen) == "" ]] && echo "Installing py_sphinx" && extension --install py_sphinx && echo "Finished py_sphinx"
	#[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
	[[ $(command -v texdoc) == "" ]] && echo "Installing texlive" && extension --install texlive && echo "Finished texlive"
	[[ $(command -v valgrind) == "" ]] && echo "Installing valgrind" && extension --install valgrind && echo "Finished valgrind"
	[[ $(command -v zip) == "" ]] && echo "Installing zip" && extension --install zip && echo "Finished zip"
	#[[ $(command -v myst-parser) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	#[[ $(command -v OCaml) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	#[[ $(command -v Z3) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v clang) == "" ]]; then
	echo "llvm" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "llvm" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
